@@ -78,11 +78,11 @@ void WaylandOutputDevice::kde_output_device_v2_mode(struct ::kde_output_device_m
     });
 }
 
-OutputPtr WaylandOutputDevice::toKScreenOutput()
+OutputPtr WaylandOutputDevice::toKScreenOutput(const QMap<int, WaylandOutputDevice *> &outputMap)
 {
     OutputPtr output(new Output());
     output->setId(m_id);
-    updateKScreenOutput(output);
+    updateKScreenOutput(output, outputMap);
     return output;
 }
 
@@ -164,7 +164,7 @@ void KScreen::WaylandOutputDevice::updateKScreenModes(OutputPtr &output)
     output->setModes(modeList);
 }
 
-void WaylandOutputDevice::updateKScreenOutput(OutputPtr &output)
+void WaylandOutputDevice::updateKScreenOutput(OutputPtr &output, const QMap<int, WaylandOutputDevice *> &outputMap)
 {
     // Initialize primary output
     output->setId(m_id);
@@ -204,6 +204,23 @@ void WaylandOutputDevice::updateKScreenOutput(OutputPtr &output)
     output->setBrightness(m_brightness / 10'000.0);
     output->setColorPowerPreference(static_cast<Output::ColorPowerTradeoff>(m_colorPowerPreference));
     output->setDimming(m_dimming / 10'000.0);
+    output->setUuid(m_uuid);
+    int replicationSourceId = 0;
+    for (auto it = outputMap.begin(); it != outputMap.end(); it++) {
+        if (it.value()->uuid() == m_replicationSource) {
+            replicationSourceId = it.key();
+            break;
+        }
+    }
+    output->setReplicationSource(replicationSourceId);
+    output->setDdcCiAllowed(m_ddcCiAllowed);
+    output->setMaxBitsPerColor(m_maxBpc);
+    output->setAutomaticMaxBitsPerColorLimit(m_autoMaxBpcLimit);
+    output->setBitsPerColorRange(Output::BpcRange{
+        .min = bpcRange.min,
+        .max = bpcRange.max,
+    });
+    output->setEdrPolicy(static_cast<Output::EdrPolicy>(m_edrPolicy));
 
     updateKScreenModes(output);
 }
@@ -223,7 +240,7 @@ WaylandOutputDeviceMode *WaylandOutputDevice::deviceModeFromId(const QString &id
     return nullptr;
 }
 
-bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, const KScreen::OutputPtr &output)
+bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, const KScreen::OutputPtr &output, const QMap<int, WaylandOutputDevice *> &outputMap)
 {
     bool changed = false;
 
@@ -333,6 +350,26 @@ bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, cons
         wlConfig->set_dimming(object(), std::round(output->dimming() * 10'000));
         changed = true;
     }
+    if (version >= KDE_OUTPUT_CONFIGURATION_V2_SET_REPLICATION_SOURCE_SINCE_VERSION) {
+        const auto source = outputMap[output->replicationSource()];
+        if (source) {
+            wlConfig->set_replication_source(object(), source->uuid());
+        } else {
+            wlConfig->set_replication_source(object(), QString());
+        }
+        changed = true;
+    }
+    if (version >= KDE_OUTPUT_CONFIGURATION_V2_SET_DDC_CI_ALLOWED_SINCE_VERSION && m_ddcCiAllowed != output->ddcCiAllowed()) {
+        wlConfig->set_ddc_ci_allowed(object(), output->ddcCiAllowed() ? 1 : 0);
+    }
+    if (version >= KDE_OUTPUT_CONFIGURATION_V2_SET_MAX_BITS_PER_COLOR_SINCE_VERSION && m_maxBpc != output->maxBitsPerColor()) {
+        wlConfig->set_max_bits_per_color(object(), output->maxBitsPerColor());
+        changed = true;
+    }
+    if (version >= KDE_OUTPUT_CONFIGURATION_V2_SET_EDR_POLICY_SINCE_VERSION && m_edrPolicy != uint32_t(output->edrPolicy())) {
+        wlConfig->set_edr_policy(object(), uint32_t(output->edrPolicy()));
+        changed = true;
+    }
 
     return changed;
 }
@@ -501,6 +538,39 @@ void WaylandOutputDevice::kde_output_device_v2_dimming(uint32_t dimming)
     m_dimming = dimming;
 }
 
+void WaylandOutputDevice::kde_output_device_v2_replication_source(const QString &source)
+{
+    m_replicationSource = source;
+}
+
+void WaylandOutputDevice::kde_output_device_v2_ddc_ci_allowed(uint32_t allowed)
+{
+    m_ddcCiAllowed = allowed == 1;
+}
+
+void WaylandOutputDevice::kde_output_device_v2_max_bits_per_color(uint32_t max_bpc)
+{
+    m_maxBpc = max_bpc;
+}
+
+void WaylandOutputDevice::kde_output_device_v2_max_bits_per_color_range(uint32_t min_value, uint32_t max_value)
+{
+    bpcRange = {
+        .min = min_value,
+        .max = max_value,
+    };
+}
+
+void WaylandOutputDevice::kde_output_device_v2_automatic_max_bits_per_color_limit(uint32_t value)
+{
+    m_autoMaxBpcLimit = value;
+}
+
+void WaylandOutputDevice::kde_output_device_v2_edr_policy(uint32_t policy)
+{
+    m_edrPolicy = policy;
+}
+
 QByteArray WaylandOutputDevice::edid() const
 {
     return m_edid;
